@@ -76,21 +76,23 @@ void ElisaConfigurationDialog::save()
     Elisa::ElisaConfiguration::setShowProgressOnTaskBar(mShowProgressInTaskBar);
     Elisa::ElisaConfiguration::setShowSystemTrayIcon(mShowSystemTrayIcon);
     Elisa::ElisaConfiguration::setForceUsageOfFastFileSearch(mForceUsageOfFastFileSearch);
+    Elisa::ElisaConfiguration::setPlayAtStartup(mPlayAtStartup);
+    Elisa::ElisaConfiguration::setColorScheme(mColorScheme);
 
-    Elisa::ElisaConfiguration::setEmbeddedView(0);
+    Elisa::ElisaConfiguration::setEmbeddedView(Elisa::ElisaConfiguration::EnumEmbeddedView::NoView);
     switch (mEmbeddedView)
     {
     case ElisaUtils::Unknown:
-        Elisa::ElisaConfiguration::setEmbeddedView(0);
+        Elisa::ElisaConfiguration::setEmbeddedView(Elisa::ElisaConfiguration::EnumEmbeddedView::NoView);
         break;
     case ElisaUtils::Album:
-        Elisa::ElisaConfiguration::setEmbeddedView(1);
+        Elisa::ElisaConfiguration::setEmbeddedView(Elisa::ElisaConfiguration::EnumEmbeddedView::AllAlbums);
         break;
     case ElisaUtils::Artist:
-        Elisa::ElisaConfiguration::setEmbeddedView(2);
+        Elisa::ElisaConfiguration::setEmbeddedView(Elisa::ElisaConfiguration::EnumEmbeddedView::AllArtists);
         break;
     case ElisaUtils::Genre:
-        Elisa::ElisaConfiguration::setEmbeddedView(3);
+        Elisa::ElisaConfiguration::setEmbeddedView(Elisa::ElisaConfiguration::EnumEmbeddedView::AllGenres);
         break;
     case ElisaUtils::Radio:
     case ElisaUtils::Track:
@@ -101,6 +103,8 @@ void ElisaConfigurationDialog::save()
         break;
     }
 
+    Elisa::ElisaConfiguration::setInitialView(mInitialViewIndex);
+
     Elisa::ElisaConfiguration::self()->save();
 
     mIsDirty = false;
@@ -155,26 +159,65 @@ void ElisaConfigurationDialog::setEmbeddedView(ElisaUtils::PlayListEntryType emb
     setDirty();
 }
 
+void ElisaConfigurationDialog::setInitialViewIndex(int initialViewIndex)
+{
+    if (mInitialViewIndex == initialViewIndex) {
+        return;
+    }
+
+    mInitialViewIndex = initialViewIndex;
+    QTimer::singleShot(0, [this](){ Q_EMIT initialViewIndexChanged(); });
+
+    setDirty();
+}
+
+void ElisaConfigurationDialog::setPlayAtStartup(bool playAtStartup)
+{
+    if (mPlayAtStartup == playAtStartup) {
+        return;
+    }
+    mPlayAtStartup = playAtStartup;
+    Q_EMIT playAtStartupChanged();
+
+    setDirty();
+}
+
+void ElisaConfigurationDialog::setColorScheme(const QString &scheme)
+{
+    if (mColorScheme == scheme) {
+        return;
+    }
+    mColorScheme = scheme;
+    Q_EMIT colorSchemeChanged();
+
+    setDirty();
+}
+
 void ElisaConfigurationDialog::configChanged()
 {
     setRootPath(Elisa::ElisaConfiguration::rootPath());
     setShowProgressInTaskBar(Elisa::ElisaConfiguration::showProgressOnTaskBar());
     setShowSystemTrayIcon(Elisa::ElisaConfiguration::showSystemTrayIcon());
+    setPlayAtStartup(Elisa::ElisaConfiguration::playAtStartup());
+    setColorScheme(Elisa::ElisaConfiguration::colorScheme());
+
     switch (Elisa::ElisaConfiguration::embeddedView())
     {
-    case 0:
+    case Elisa::ElisaConfiguration::EnumEmbeddedView::NoView:
         setEmbeddedView(ElisaUtils::Unknown);
         break;
-    case 1:
+    case Elisa::ElisaConfiguration::EnumEmbeddedView::AllAlbums:
         setEmbeddedView(ElisaUtils::Album);
         break;
-    case 2:
+    case Elisa::ElisaConfiguration::EnumEmbeddedView::AllArtists:
         setEmbeddedView(ElisaUtils::Artist);
         break;
-    case 3:
+    case Elisa::ElisaConfiguration::EnumEmbeddedView::AllGenres:
         setEmbeddedView(ElisaUtils::Genre);
         break;
     }
+
+    setInitialViewIndex(Elisa::ElisaConfiguration::initialView());
 }
 
 void ElisaConfigurationDialog::setDirty()
