@@ -63,7 +63,7 @@ MediaPlayer2Player::MediaPlayer2Player(MediaPlayListProxyModel *playListControle
     connect(m_audioPlayer, &AudioWrapper::volumeChanged,
             this, &MediaPlayer2Player::playerVolumeChanged);
 
-    m_volume = m_audioPlayer->volume();
+    m_volume = m_audioPlayer->volume() / 100;
     m_canPlay = m_manageMediaPlayerControl->playControlEnabled();
     signalPropertiesChange(QStringLiteral("Volume"), Volume());
 
@@ -133,7 +133,7 @@ void MediaPlayer2Player::Previous()
     emit previous();
 
     if (m_playListControler) {
-        m_playListControler->skipPreviousTrack();
+        m_playListControler->skipPreviousTrack(m_audioPlayer->position());
     }
 }
 
@@ -386,12 +386,19 @@ void MediaPlayer2Player::setCurrentTrack(int newTrackPosition)
     m_currentTrackId = QDBusObjectPath(QLatin1String("/org/kde/elisa/playlist/") + QString::number(newTrackPosition)).path();
 
     emit currentTrackChanged();
+
+    m_metadata = getMetadataOfCurrentTrack();
+    signalPropertiesChange(QStringLiteral("Metadata"), Metadata());
 }
 
 QVariantMap MediaPlayer2Player::getMetadataOfCurrentTrack()
 {
     auto result = QVariantMap();
 
+    if (m_currentTrackId.isEmpty()) {
+        return {};
+    }
+
     result[QStringLiteral("mpris:trackid")] = QVariant::fromValue<QDBusObjectPath>(QDBusObjectPath(m_currentTrackId));
     result[QStringLiteral("mpris:length")] = qlonglong(m_manageAudioPlayer->audioDuration()) * 1000;
     //convert milli-seconds into micro-seconds
