@@ -1,18 +1,7 @@
 /*
- * Copyright 2016-2017 Matthieu Gallien <matthieu_gallien@yahoo.fr>
- *
- * This program is free software: you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   SPDX-FileCopyrightText: 2016 (c) Matthieu Gallien <matthieu_gallien@yahoo.fr>
+
+   SPDX-License-Identifier: LGPL-3.0-or-later
  */
 
 #include "musiclistenersmanager.h"
@@ -150,7 +139,13 @@ MusicListenersManager::MusicListenersManager(QObject *parent)
 }
 
 MusicListenersManager::~MusicListenersManager()
-= default;
+{
+    d->mListenerThread.quit();
+    d->mListenerThread.wait();
+
+    d->mDatabaseThread.quit();
+    d->mDatabaseThread.wait();
+}
 
 DatabaseInterface *MusicListenersManager::viewDatabase() const
 {
@@ -303,6 +298,7 @@ void MusicListenersManager::deleteElementById(ElisaUtils::PlayListEntryType entr
     case ElisaUtils::Track:
     case ElisaUtils::FileName:
     case ElisaUtils::Unknown:
+    case ElisaUtils::Container:
         break;
     }
 }
